@@ -66,16 +66,16 @@ class Api(object):
         return self.db_client.benchmark_resource.search(project_name, begin_time, end_time, test_name)
 
     def get_test_detail_information(self, test_key):
-        self.db_client.benchmark_resource.get_test_detail_information(test_key)
+        return self.db_client.benchmark_resource.get_test_detail_information(test_key)
 
     def get_step_detail_information(self, step_key):
-        self.db_client.benchmark_resource.get_step_detail_information(step_key)
+        return self.db_client.benchmark_resource.get_step_detail_information(step_key)
 
     def get_real_time_results(self, key, mini_index=None):
-        self.db_client.benchmark_resource.get_real_time_results(key, mini_index)
+        return self.db_client.benchmark_resource.get_real_time_results(key, mini_index)
 
     def get_test_state(self, key):
-        self.db_client.benchmark_resource.get_test_state(key)
+        return self.db_client.benchmark_resource.get_test_state(key)
 
 
 # if __name__ == '__main__':
