@@ -169,14 +169,6 @@ class BenchmarkDBResource(object):
             result = results[0][0]
         return result
 
-    def _get_index_by_key(self, key):
-        result = None
-        command = "SELECT `index` FROM _tests WHERE `key`='{}'".format(key)
-        results = self.sql.execute_sql_command(command)
-        if results:
-            result = results[0][0]
-        return result
-
     def _search_tests_by_group_key(self, group_key):
         sea_string = "SELECT * FROM _tests WHERE group_key='{}'".format(group_key)
         result = self.sql.execute_sql_command(sea_string)
@@ -191,6 +183,14 @@ class BenchmarkDBResource(object):
         sea_string = "SELECT * FROM _tests WHERE `key`='{}'".format(step_key)
         result = self.sql.execute_sql_command(sea_string)
         return result
+    
+    def get_index_by_key(self, key):
+        result = None
+        command = "SELECT `index` FROM _tests WHERE `key`='{}'".format(key)
+        results = self.sql.execute_sql_command(command)
+        if results:
+            result = results[0][0]
+        return result
 
     def confirm_test(self, step_key):
         """
@@ -308,7 +308,7 @@ class BenchmarkDBResource(object):
         :param mini_index: get the real time data index more then the mini_index
         :return:
         """
-        index = self._get_index_by_key(key)
+        index = self.get_index_by_key(key)
         result = self._get_real_time_results(index, mini_index)
         return result
 
@@ -318,5 +318,5 @@ class BenchmarkDBResource(object):
         :param key:
         :return:
         """
-        index = self._get_index_by_key(key)
+        index = self.get_index_by_key(key)
         return self._get_test_state_by_index(index)
