@@ -38,8 +38,13 @@ class EnvDBResource(object):
             start_time = None
             work_time_list = list()
             for item in value:
-                if item[1] == "running" and start_time is None:
-                    start_time = item[2]
+                if item[1] == "running":
+                    if start_time is None:
+                        start_time = item[2]
+                    else:
+                        temp_work_time = item[2] - start_time
+                        work_time_list.append(temp_work_time.total_seconds())
+                        start_time = item[2]
                 elif item[1] == "idle" and start_time is not None:
                     temp_work_time = item[2] - start_time
                     work_time_list.append(temp_work_time.total_seconds())
@@ -97,8 +102,9 @@ class EnvDBResource(object):
         cmd = "UPDATE node SET project='{}' where `ip`='{}'".format(project_name, ip)
         self.sql.cursor.execute(cmd)
         self.sql.conn.commit()
-#
-# if __name__ == '__main__':
-#     DB = EnvDBResource()
-#     aa = DB.get_node_usage_rate("172.29.131.80")
-#     pass
\ No newline at end of file
+
+
+if __name__ == '__main__':
+    DB = EnvDBResource()
+    aa = DB.get_node_usage_rate("172.29.131.117")
+    pass
\ No newline at end of file
